@@ -561,12 +561,12 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  out.close();
 	  COUT << "File " << outfile << " created" << outfile << '\n' << "Then I will run pdflatex " << giac::remove_extension(outfile) << '\n' ;
 	  if (dohevea){
-	    std::string cmd="hevea -fix "+infile_+" &";
+	    std::string cmd="hevea2mml "+infile_+" &";
 	    COUT << "Running " << cmd << '\n';
 	    giac::system_no_deprecation(cmd.c_str());
 	  }
 	  else
-	    COUT << "For HTML5 output, you can run\nhevea -fix " << infile_ << '\n';
+	    COUT << "For HTML5 output, you can run\nhevea2mml " << infile_ << '\n';
 	  std::string cmd="makeindex "+giac::remove_extension(outfile);
 	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+infile_+".pdf");
@@ -822,8 +822,8 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	if (pos>=0 && pos<ss){
 	  out << s << '\n';
 	  out.close();
-	  COUT << "File " << outfile << " created, now running hevea in background and pgiac " << outfile << '\n' << "Then I will run pdflatex " << giac::remove_extension(outfile) << '\n' << "For HTML5 output, you can run\nhevea -fix " << giac::remove_extension(infile) << '\n';
-	  std::string cmd="hevea -fix "+giac::remove_extension(infile)+" &";
+	  COUT << "File " << outfile << " created, now running hevea2mml in background and pgiac " << outfile << '\n' << "Then I will run pdflatex " << giac::remove_extension(outfile) << '\n' << "For HTML5 output, you can run\nhevea2mml " << giac::remove_extension(infile) << '\n';
+	  std::string cmd="hevea2mml "+giac::remove_extension(infile)+" &";
 	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pgiac "+outfile+" && pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+giac::remove_extension(infile)+".pdf");
 	  COUT << cmd << '\n';
