@@ -64,11 +64,11 @@ namespace giac {
   unsigned gl_translate(unsigned i);
   // utilities for matrix 4x4 represented as a double[16] 
   // written in columns
-  void mult4(double * colmat,double * vect,double * res);
-  void mult4(double * colmat,float * vect,double * res);
-  void mult4(double * c,double k,double * res);
-  double det4(double * c);
-  void inv4(double * c,double * res);
+  void mult4ddd(double * colmat,double * vect,double * res);
+  void mult4dfd(double * colmat,float * vect,double * res);
+  void mult4d(double * c,double k,double * res);
+  double det4d(double * c);
+  void inv4d(double * c,double * res);
   // return in i and j the distance to the BOTTOM LEFT of the window
   // use window()->h()-j for the FLTK coordinates in this window
   void dim32dim2(double * view,double * proj,double * model,double x0,double y0,double z0,double & i,double & j,double & depth);
